/*
   FNT - SQL-backend for SQLite3 - function connect

   Copyright (C) 2009 Free Software Foundation, Inc.

   Written by:
   Slava Zanko <slavazanko@gmail.com>


   This file is part of the FIDO New Technology.

   FIDO New Technology is free software: you can redistribute it and/or 
   modify it under the terms of the GNU General Public License as published 
   by the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#ifdef HAVE_CONFIG_H
#	include <config.h>
#endif

#include <sqlite3.h>
#include <stdlib.h>
#include <string.h>

#include "../include/global.h"

#include "../include/types.h"
#include "../include/error.h"
#include "../include/plugin.h"
#include "../include/sql.h"

#include "main.h"

/*** global variables **************************************************/

/*** file scope macro definitions **************************************/

/*** file scope type declarations **************************************/

/*** file scope variables **********************************************/

/*** file scope functions **********************************************/

/*** public functions **************************************************/

DLLEXPORT fnt_sql_connect_t *
fntsql_connect (void)
{
    fnt_sql_connect_t *sql_connect;
    sqlite3 *handle;

    if (connect_info.is_local_path == false)
    {
	fnt_error_push (FNT_MODULE_sql, FNT_SQL_E_DRIVER,
			_
			("Sqlite3 - unsupported connection type (non-local)"));
	return NULL;
    }

    if (sqlite3_open (connect_info.local_db_path, &handle))
    {
	fnt_error_push (FNT_MODULE_sql, FNT_SQL_E_DRIVER,
			_("Sqlite3 - an error occured while connect: %s"),
			sqlite3_errmsg (handle));
	sqlite3_close (handle);
	return NULL;
    }

    sql_connect = g_try_malloc (sizeof (fnt_sql_connect_t));
    if (sql_connect == NULL)
    {
	sqlite3_close (handle);
	return NULL;
    }


    sql_connect->info = g_try_malloc (sizeof (fnt_sql_connect_info_t));
    if (sql_connect->info == NULL)
    {
	sqlite3_close (handle);
	g_free (sql_connect);
	return NULL;
    }

    sql_connect->db_handle = (void *) handle;
    memcpy ((void *) sql_connect->info, (void *) &connect_info,
	    sizeof (fnt_sql_connect_info_t));
    sql_connect->info->local_db_path = g_strdup (connect_info.local_db_path);
    sql_connect->info->db_name = g_strdup ("");
    sql_connect->info->host_name = g_strdup ("");
    sql_connect->info->user_name = g_strdup ("");
    sql_connect->info->password = g_strdup ("");
    sql_connect->info->port_number = 0;
    return sql_connect;
}
